@@ -17,3 +17,18 @@ test_that("End to get the last element gets replaced", {
 	res <- convSymbols(linesMat)
 	expect_true(!is.na(match(res, "thing{length(thing)}")))
 })
+
+test_that("dot syntax gets replaced", {
+	linesMat <- c("A.*B")
+	res <- convDotSyntax(linesMat)
+	expect_true(!is.na(match(res, "A*B")))
+	
+})
+
+test_that("regular dots don't get replaced", {
+	linesMat <- c("student.name")
+	res <- convDotSyntax(linesMat)
+	expect_true(!is.na(match(res, "student.name")))
+	
+	
+})
